==> marray-0.99.tar.gz: marray-0.99/src/oper.c <==
#include <config.h>
#include <stdlib.h>
#include <math.h>
#include <gsl/gsl_math.h>
#include "marray.h"

/* #define BASE_GSL_COMPLEX_LONG */
/* #include "templates_on.h" */
/* #include "oper_complex_source.c" */
/* #include "templates_off.h" */
/* #undef  BASE_GSL_COMPLEX_LONG */

/* #define BASE_GSL_COMPLEX */
/* #include "templates_on.h" */
/* #include "oper_complex_source.c" */
/* #include "templates_off.h" */
/* #undef  BASE_GSL_COMPLEX */

/* #define BASE_GSL_COMPLEX_FLOAT */
/* #include "templates_on.h" */
/* #include "oper_complex_source.c" */
/* #include "templates_off.h" */
/* #undef  BASE_GSL_COMPLEX_FLOAT */

#define BASE_LONG_DOUBLE
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_LONG_DOUBLE

#define BASE_DOUBLE
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_DOUBLE

#define BASE_FLOAT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_FLOAT

#define BASE_ULONG
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_ULONG

#define BASE_LONG
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_LONG

#define BASE_UINT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_UINT

#define BASE_INT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_INT

#define BASE_USHORT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_USHORT

#define BASE_SHORT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_SHORT

#define BASE_UCHAR
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_UCHAR

#define BASE_CHAR
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_CHAR

==> marray-2.0.tar.gz: marray-2.0/src/oper.c <==
#include <config.h>
#include <stdlib.h>
#include <math.h>
#include <gsl/gsl_math.h>
#include "marray.h"

#define BASE_COMPLEX_DOUBLE
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_COMPLEX_DOUBLE

#define BASE_LONG_DOUBLE
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_LONG_DOUBLE

#define BASE_DOUBLE
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_DOUBLE

#define BASE_FLOAT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_FLOAT

#define BASE_ULONG
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_ULONG

#define BASE_LONG
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_LONG

#define BASE_UINT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_UINT

#define BASE_INT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_INT

#define BASE_USHORT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_USHORT

#define BASE_SHORT
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_SHORT

#define BASE_UCHAR
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_UCHAR

#define BASE_CHAR
#include "templates_on.h"
#include "oper_source.c"
#include "templates_off.h"
#undef  BASE_CHAR
